@@ -13,10 +13,15 @@ User = get_user_model()
 
 class Migration(DataMigration):
 
+    depends_on = (
+        ("articles", "0001_initial"),
+    )
+
     def forwards(self, orm):
         for post in Post.objects.all():
             for r in post.postrelated_post.all():
-                p, c = post.containerrelated_container.get_or_create(related=r)
+                p, c = post.containerrelated_container.get_or_create(
+                    related=r.related)
 
     def backwards(self, orm):
         raise RuntimeError("Cannot reverse this migration.")
